@@ -1,3 +1,5 @@
+import multiprocessing as mp
+
 from typing import Union, Dict, Optional, Set, Any, Callable, Hashable
 
 import torch.cuda
@@ -15,6 +17,13 @@ from quaterion.train.encoders import (
 
 
 class CacheMixin:
+    # Child processes need to derive randomized `PYTHONHASHSEED` value from
+    # parent process. It is only done with `fork` start method.
+    # `fork` start method is presented on Unix systems and it is the
+    # default for them, except macOS. Therefore, we set `fork` method
+    # explicitly and cache is not supported on Windows.
+    CACHE_MULTIPROCESSING_CONTEXT = "fork"
+
     @classmethod
     def apply_cache_config(
         cls,
@@ -53,7 +62,10 @@ class CacheMixin:
                 ] = cache_config.key_extractors.get(encoder_name)
 
                 encoders[encoder_name]: CacheEncoder = cls.wrap_encoder(
-                    encoder, cache_type, key_extractor, encoder_name,
+                    encoder,
+                    cache_type,
+                    key_extractor,
+                    encoder_name,
                 )
 
                 possible_cache_encoders.remove(encoder_name)
@@ -71,7 +83,10 @@ class CacheMixin:
             cls._check_cuda(cache_config.cache_type, encoder_name)
             key_extractor = cache_config.key_extractors.get(encoder_name)
             encoders = cls.wrap_encoder(
-                encoders, cache_config.cache_type, key_extractor, encoder_name,
+                encoders,
+                cache_config.cache_type,
+                key_extractor,
+                encoder_name,
             )
         else:
             raise ValueError(
@@ -108,9 +123,13 @@ class CacheMixin:
 
         return encoder
 
-    @staticmethod
+    @classmethod
     def cache(
-        encoders, train_dataloader: DataLoader, val_dataloader: Optional[DataLoader],
+        cls,
+        encoders,
+        train_dataloader: DataLoader,
+        val_dataloader: Optional[DataLoader],
+        cache_config: CacheConfig,
     ) -> None:
         """
         Fill cache for each CacheEncoder
@@ -118,6 +137,7 @@ class CacheMixin:
         :param encoders: MetricModel
         :param train_dataloader:
         :param val_dataloader:
+        :param cache_config:
         :return: None
         """
         cache_encoders = {
@@ -130,15 +150,40 @@ class CacheMixin:
             return
 
         def cache_dataloader(dataloader):
-            for sample in dataloader:
+            cache_dl = DataLoader(
+                dataset=dataloader.dataset,
+                batch_size=cache_config.batch_size,
+                collate_fn=dataloader.collate_fn,
+                num_workers=dataloader.num_workers,
+                pin_memory=dataloader.pin_memory,
+                timeout=dataloader.timeout,
+                worker_init_fn=dataloader.worker_init_fn,
+                prefetch_factor=dataloader.prefetch_factor,
+            )
+            for sample in cache_dl:
                 features, _ = sample
                 for name, encoder in cache_encoders.items():
                     encoder.fill_cache(features[name])
 
+        cls.switch_multiprocessing_context(train_dataloader)
         cache_dataloader(train_dataloader)
-        val_dataloader = val_dataloader if val_dataloader is not None else []
-        cache_dataloader(val_dataloader)
+
+        if val_dataloader is not None:
+            cls.switch_multiprocessing_context(val_dataloader)
+            cache_dataloader(val_dataloader)
 
         # Once cache is filled, collate functions return only keys for cache
         for encoder_name in cache_encoders:
             encoders[encoder_name].cache_filled = True
+
+    @classmethod
+    def switch_multiprocessing_context(cls, *dataloaders):
+        if cls.CACHE_MULTIPROCESSING_CONTEXT not in mp.get_all_start_methods():
+            raise OSError(
+                f"Cache can't be used. {cls.CACHE_MULTIPROCESSING_CONTEXT} "
+                "multiprocessing context is not available on current OS"
+            )
+
+        for dataloader in dataloaders:
+            if dataloader is not None:
+                dataloader.multiprocessing_context = cls.CACHE_MULTIPROCESSING_CONTEXT
